@@ -439,7 +439,7 @@ class JobMonitor(MessageCore):
       newJobId      = ""
 
       message = self.receiveMessage(channel,self.fixedBufferSize)
-      if message != "":
+      if message:
          if   re.match('[QSRT]:',message):
             nInstances = 0
             try:
